@@ -1,5 +1,5 @@
 package Apache::AuthCookie::Util;
-$Apache::AuthCookie::Util::VERSION = '3.21';
+$Apache::AuthCookie::Util::VERSION = '3.22';
 # ABSTRACT: Internal Utility Functions for AuthCookie
 
 use strict;
@@ -67,7 +67,7 @@ sub expire_calc {
 sub escape_destination {
     my $text = shift;
 
-    $text =~ s/([\r\n\t])/sprintf("%%%02X", ord $1)/ge;
+    $text =~ s/([\r\n\t\>\<"])/sprintf("%%%02X", ord $1)/ge;
 
     return $text;
 }
@@ -96,7 +96,7 @@ Apache::AuthCookie::Util - Internal Utility Functions for AuthCookie
 
 =head1 VERSION
 
-version 3.21
+version 3.22
 
 =head1 SOURCE
 
